translate.lang.th

Package translate :: Package lang :: Module th |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.th

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module represents Thai language.
    23
    24  For more information, see U{http://en.wikipedia.org/wiki/Thai_language}
    25  """
    26
    27  from translate.lang import common
    28
    29
    30 -class th(common.Common):
    31      """This class represents Thai."""
    32
    33      puncdict = {
    34          u". ": u" ",
    35          #u"; ": u" ", # Test interaction with XML entities
    36      }
    37
    38      # No capitalisation. While we can't do sentence segmentation, sentencecount
    39      # is useless.
    40      ignoretests = ["startcaps", "simplecaps", "sentencecount"]
    41